About Zen-Knit:
---------------

Zen-Knit is a formal (PDF), informal (HTML) report generator for data analyst and data scientist who wants to use python. Inspired from Pweave. 
Zen-Knit is good for creating reports, tutorials with embedded python

Features:
---------

* Python 3.6+ compatibility
* Support for IPython magics and rich output.
* **Execute python code** in the chunks and **capture** input and output to a report.
* **Use hidden code chunks,** i.e. code is executed, but not printed in the output file.
* Capture matplotlib graphics.
* Evaluate inline code in documentation chunks marked using ```{ }`` 
* Publish reports from Python scripts. Similar to R markdown.

Install
-----------------------

From PyPi::

  pip install --upgrade zen-knit

or download the source and run::

  python setup.py install



License information
-------------------

See the file "LICENSE" for information on the history of this
software, terms & conditions for usage, and a DISCLAIMER OF ALL
WARRANTIES.